@@ -1,3 +1,5 @@
+from __future__ import absolute_import
+
 """
 M2Crypto is the most complete Python wrapper for OpenSSL featuring RSA, DSA,
 DH, EC, HMACs, message digests, symmetric ciphers (including AES); SSL
@@ -13,48 +15,27 @@ Copyright (c) 1999-2004 Ng Pheng Siong. All rights reserved.
 Portions created by Open Source Applications Foundation (OSAF) are
 Copyright (C) 2004-2007 OSAF. All Rights Reserved.
 
-Copyright 2008-2010 Heikki Toivonen. All rights reserved.
+Copyright 2008-2011 Heikki Toivonen. All rights reserved.
 """
+# noqa
+from distutils.version import StrictVersion
+__version__ = '0.26.4'
+version = __version__  # type: str
+version_info = StrictVersion(__version__).version
 
-version_info = (0, 21)
-version = '.'.join([str(_v) for _v in version_info])
+from M2Crypto import (ASN1, AuthCookie, BIO, BN, DH, DSA, EVP, Engine, Err,
+                      PGP, RSA, Rand, SMIME, SSL, X509, m2crypto,
+                      ftpslib, httpslib, m2, m2urllib, m2xmlrpclib,
+                      threading, util)
 
-import __m2crypto
-import m2
-import ASN1
-import AuthCookie
-import BIO
-import BN
-import Rand
-import DH
-import DSA
 if m2.OPENSSL_VERSION_NUMBER >= 0x90800F and m2.OPENSSL_NO_EC == 0:
-    import EC
-import Err
-import Engine
-import EVP
-import RSA
-import RC4
-import SMIME
-import SSL
-import X509
-import PGP
-import m2urllib
+    from M2Crypto import EC
+if m2.OPENSSL_NO_RC4 == 0:
+    from M2Crypto import RC4
 # Backwards compatibility.
 urllib2 = m2urllib
 
-import sys
-if sys.version_info >= (2,4):
-    import m2urllib2
-del sys
+encrypt = 1
+decrypt = 0
 
-import ftpslib
-import httpslib
-import m2xmlrpclib
-import threading
-import util
-
-encrypt=1
-decrypt=0
-
-__m2crypto.lib_init()
+m2crypto.lib_init()
